@@ -334,7 +334,11 @@ class Router(object):
                     await send({'type': 'lifespan.shutdown.complete'})
 
         metadata = preprocessor(scope)
-        engine = self.subdomains.get(metadata[0]) or self.subdomains.get(DEFAULT)
+        subdomain = metadata[0]
+        wildcard_engine = self.subdomains.get(WILDCARD)
+        engine = self.subdomains.get(subdomain):
+        if not engine:
+            engine = wildcard_engine if wildcard_engine else self.subdomains.get(DEFAULT)
 
         response = await engine.handle(scope, receive, send, metadata, self)
         await send({'type': 'http.response.start', 'headers': response.headers, 'status': response.status})
